@@ -5,7 +5,6 @@
 #    @Pip-Library: https://pypi.org/project/ndn-svs/
 
 # Basic Libraries
-import logging
 from typing import Optional, Callable
 # NDN Imports
 from ndn.app import NDNApp
@@ -17,6 +16,7 @@ from ndn_python_repo import Storage
 from .core import SVSyncCore
 from .storage import SVSyncStorage
 from .security import SecurityOptions, SigningInfo, ValidatingInfo
+from .logger import SVSyncLogger
 
 # Class Type: an abstract API class
 # Class Purpose:
@@ -24,7 +24,7 @@ from .security import SecurityOptions, SigningInfo, ValidatingInfo
 #   to allow the user to interact with SVS, fetch and publish.
 class SVSyncBase():
     def __init__(self, app:NDNApp, syncPrefix:Name, dataPrefix:Name, groupPrefix:Name, nid:Name, updateCallback:Callable, storage:Optional[Storage]=None, securityOptions:Optional[SecurityOptions]=None) -> None:
-        logging.info(f'SVSync: started svsync')
+        SVSyncLogger.info(f'SVSync: started svsync')
         self.app = app
         self.storage = SVSyncStorage() if not storage else storage
         self.syncPrefix = syncPrefix
@@ -35,43 +35,43 @@ class SVSyncBase():
         self.secOptions = securityOptions if securityOptions is not None else SecurityOptions(SigningInfo(SignatureType.DIGEST_SHA256), ValidatingInfo(ValidatingInfo.get_validator(SignatureType.DIGEST_SHA256)), SigningInfo(SignatureType.DIGEST_SHA256), [])
         self.core = SVSyncCore(self.app, self.syncPrefix, self.groupPrefix, self.nid, self.updateCallback, self.secOptions)
         self.app.route(self.dataPrefix)(self.onDataInterest)
-        logging.info(f'SVSync: started listening to {Name.to_str(self.dataPrefix)}')
+        SVSyncLogger.info(f'SVSync: started listening to {Name.to_str(self.dataPrefix)}')
     def onDataInterest(self, int_name:FormalName, int_param:InterestParam, _app_param:Optional[BinaryStr]) -> None:
         data_pkt = self.storage.get_data_packet(int_name, int_param.can_be_prefix)
         if data_pkt:
-            logging.info(f'SVSync: served data {Name.to_str(int_name)}')
+            SVSyncLogger.info(f'SVSync: served data {Name.to_str(int_name)}')
             self.app.put_raw_packet(data_pkt)
     async def fetchData(self, nid:Name, seqNum:int, retries:int=0) -> Optional[bytes]:
         name = self.getDataName(nid, seqNum)
         while retries+1 > 0:
             try:
-                logging.info(f'SVSync: fetching data {Name.to_str(name)}')
+                SVSyncLogger.info(f'SVSync: fetching data {Name.to_str(name)}')
                 _, _, _, pkt = await self.app.express_interest(name, need_raw_packet=True, must_be_fresh=True, can_be_prefix=False, lifetime=6000)
                 ex_int_name, meta_info, content, sig_ptrs = parse_data(pkt)
                 isValidated = await self.secOptions.validate(ex_int_name, sig_ptrs)
                 if not isValidated:
                     return None
-                logging.info(f'SVSync: received data {bytes(content)}')
+                SVSyncLogger.info(f'SVSync: received data {bytes(content)}')
                 return bytes(content) if content else None
             except InterestNack as e:
-                logging.warning(f'SVSync: nacked with reason={e.reason}')
+                SVSyncLogger.warning(f'SVSync: nacked with reason={e.reason}')
             except InterestTimeout:
-                logging.warning(f'SVSync: timeout')
+                SVSyncLogger.warning(f'SVSync: timeout')
             except InterestCanceled:
-                logging.warning(f'SVSync: canceled')
+                SVSyncLogger.warning(f'SVSync: canceled')
             except ValidationFailure:
-                logging.warning(f'SVSync: data failed to validate')
+                SVSyncLogger.warning(f'SVSync: data failed to validate')
             except Exception as e:
-                logging.warning(f'SVSync: unknown error has occured: {e}')
+                SVSyncLogger.warning(f'SVSync: unknown error has occured: {e}')
 
             retries = retries - 1
             if retries+1 > 0:
-                logging.info(f'SVSync: retrying fetching data')
+                SVSyncLogger.info(f'SVSync: retrying fetching data')
         return None
     def publishData(self, data:bytes) -> None:
         name = self.getDataName(self.nid, self.core.getSeqNum()+1)
         data_packet = make_data(name, MetaInfo(freshness_period=5000), content=data, signer=self.secOptions.dataSig.signer)
-        logging.info(f'SVSync: publishing data {Name.to_str(name)}')
+        SVSyncLogger.info(f'SVSync: publishing data {Name.to_str(name)}')
         self.storage.put_data_packet(name, data_packet)
         self.core.updateMyState(self.core.getSeqNum()+1)
     def getCore(self) -> SVSyncCore:
